@@ -67,6 +67,7 @@ from unyt._physical_ratios import (
     eps_0,
     mu_0,
     avogadros_number,
+    neper_per_bel,
 )
 import numpy as np
 
@@ -114,6 +115,7 @@ default_unit_symbol_lut = OrderedDict(
         ("bar", (1.0e5, dimensions.pressure, 0.0, r"\rm{bar}", True)),
         ("V", (1.0, dimensions.electric_potential, 0.0, r"\rm{V}", True)),
         ("F", (1.0, dimensions.capacitance, 0.0, r"\rm{F}", True)),
+        ("H", (1.0, dimensions.inductance, 0.0, r"\rm{H}", True)),
         ("Ω", (1.0, dimensions.resistance, 0.0, r"\Omega", True)),
         ("Wb", (1.0, dimensions.magnetic_flux, 0.0, r"\rm{Wb}", True)),
         ("lm", (1.0, dimensions.luminous_flux, 0.0, r"\rm{lm}", True)),
@@ -267,6 +269,9 @@ default_unit_symbol_lut = OrderedDict(
                 False,
             ),
         ),
+        # logarithmic units
+        ("B", (neper_per_bel, dimensions.logarithmic, 0.0, r"\rm{B}", True)),
+        ("Np", (1.0, dimensions.logarithmic, 0.0, r"\rm{Np}", True)),
     ]
 )
 
@@ -346,7 +351,14 @@ physical_constants = OrderedDict(
         ("hbar", (0.5 * planck_mks / np.pi, "J*s", ["reduced_planck_constant"])),
         ("σ", (5.670373e-8, "W/m**2/K**4", ["stefan_boltzmann_constant"])),
         ("Tcmb", (2.726, "K", ["CMB_temperature"])),
-        ("Msun", (mass_sun_kg, "kg", ["msun", "solar_mass", "mass_sun"])),
+        (
+            "Msun",
+            (
+                mass_sun_kg,
+                "kg",
+                ["msun", "m_sun", "m_Sun", "M_sun", "M_Sun", "solar_mass", "mass_sun"],
+            ),
+        ),
         ("Mjup", (mass_jupiter_kg, "kg", ["mjup", "jupiter_mass", "mass_jupiter"])),
         ("mercury_mass", (mass_mercury_kg, "kg", ["mass_mercury"])),
         ("venus_mass", (mass_venus_kg, "kg", ["mass_venus"])),
@@ -404,17 +416,18 @@ default_unit_name_alternatives = OrderedDict(
         ("Pa", ("pascal",)),
         ("V", ("volt",)),
         ("F", ("farad",)),
+        ("H", ("henry",)),
         ("Ω", ("ohm", "Ohm")),
         ("Wb", ("weber",)),
         ("lm", ("lumen",)),
         ("lx", ("lux",)),
-        ("degC", ("degree_celsius", "celcius")),
+        ("degC", ("degree_celsius", "degree_Celsius", "celcius", "celsius", "°C")),
         # Imperial and other non-metric units
         ("inch", ("in",)),
         ("ft", ("foot",)),
         ("yd", ("yard",)),
         ("furlong", ("fur",)),
-        ("degF", ("degree_fahrenheit", "fahrenheit")),
+        ("degF", ("degree_fahrenheit", "degree_Fahrenheit", "fahrenheit", "°F")),
         ("R", ("degree_rankine", "rankine")),
         ("lbf", ("pound_force",)),
         ("lb", ("pound", "pound_mass", "lbm")),
@@ -426,17 +439,31 @@ default_unit_name_alternatives = OrderedDict(
         ("psi", ("pounds_per_square_inch",)),
         # dimensionless stuff
         ("dimensionless", ("_", "")),
+        ("B", ("bel",)),
+        ("Np", ("neper",)),
         # times
         ("min", ("minute",)),
         ("hr", ("hour",)),
         ("day", ("d",)),
         ("yr", ("year",)),
         # Solar units
-        ("Msun", ("solar_mass", "solMass")),
-        ("Rsun", ("rsun", "r_sun", "solar_radius", "solRadius")),
-        ("Lsun", ("lsun", "l_sun", "solar_luminosity", "solLuminosity")),
-        ("Tsun", ("t_sun", "solar_temperature", "solTemperature")),
-        ("Zsun", ("z_sun", "solar_metallicity", "solMetallicity")),
+        (
+            "Msun",
+            ("msun", "m_sun", "M_sun", "m_Sun", "solar_mass", "solMass", "mass_sun"),
+        ),
+        ("Rsun", ("rsun", "r_sun", "R_sun", "r_Sun", "solar_radius", "solRadius")),
+        (
+            "Lsun",
+            ("lsun", "l_sun", "L_sun", "l_Sun", "solar_luminosity", "solLuminosity"),
+        ),
+        (
+            "Tsun",
+            ("t_sun", "tsun", "T_sun", "t_Sun", "solar_temperature", "solTemperature"),
+        ),
+        (
+            "Zsun",
+            ("z_sun", "zsun", "Z_sun", "z_Sun", "solar_metallicity", "solMetallicity"),
+        ),
         ("Mjup", ("m_jup", "jupiter_mass")),
         ("Mearth", ("m_earth", "earth_mass")),
         ("Rjup", ("r_jup", "jupiter_radius")),
@@ -498,8 +525,10 @@ def generate_name_alternatives():
         # Are we SI prefixable or not?
         if entry[4]:
             for prefix in unit_prefixes:
-                if prefix in ["u", "μ"]:
-                    used_prefix = "µ"
+                # This is specifically to work around
+                # https://github.com/yt-project/unyt/issues/145
+                if prefix in ["u", "μ", "µ"]:
+                    used_prefix = "μ"
                 else:
                     used_prefix = prefix
                 append_name(names[prefix + key], used_prefix + key, prefix + key)
