@@ -133,6 +133,7 @@ from unyt.unit_registry import (
     _sanitize_unit_system,
     UnitRegistry,
     default_unit_registry,
+    _correct_old_unit_registry,
 )
 
 NULL_UNIT = Unit()
@@ -355,6 +356,10 @@ class unyt_array(np.ndarray):
         corrupted, invalid units or array data, but can lead to significant
         speedups in the input validation logic adds significant overhead. If
         set, input_units *must* be a valid unit object. Defaults to False.
+    name : string
+        The name of the array. Defaults to None. This attribute does not propagate
+        through mathematical operations, but is preserved under indexing
+        and unit conversions.
 
     Examples
     --------
@@ -482,6 +487,7 @@ class unyt_array(np.ndarray):
         dtype=None,
         bypass_validation=False,
         input_units=None,
+        name=None,
     ):
         # deprecate input_units in favor of units
         if input_units is not None:
@@ -499,6 +505,7 @@ class unyt_array(np.ndarray):
             obj.units = input_units
             if registry is not None:
                 obj.units.registry = registry
+            obj.name = name
             return obj
         if isinstance(input_array, unyt_array):
             ret = input_array.view(cls)
@@ -512,6 +519,7 @@ class unyt_array(np.ndarray):
                 ret.units = input_units
             else:
                 ret.units = Unit(input_units, registry=registry)
+            ret.name = name
             return ret
         elif isinstance(input_array, np.ndarray):
             pass
@@ -539,9 +547,9 @@ class unyt_array(np.ndarray):
             # it's a str.
             units = Unit(input_units, registry=registry)
 
-        # Attach the units
+        # Attach the units and name
         obj.units = units
-
+        obj.name = name
         return obj
 
     def __repr__(self):
@@ -816,7 +824,13 @@ class unyt_array(np.ndarray):
             if offset:
                 np.subtract(ret, offset, ret)
 
-            new_array = type(self)(ret, new_units, bypass_validation=True)
+            try:
+                new_array = type(self)(
+                    ret, new_units, bypass_validation=True, name=self.name
+                )
+            except TypeError:
+                # subclasses might not take name as a kwarg
+                new_array = type(self)(ret, new_units, bypass_validation=True)
 
             return new_array
         else:
@@ -986,7 +1000,7 @@ class unyt_array(np.ndarray):
 
     def convert_to_equivalent(self, unit, equivalence, **kwargs):
         """
-        Return a copy of the unyt_array in the units specified units, assuming
+        Convert the array in-place to the specified units, assuming
         the given equivalency. The dimensions of the specified units and the
         dimensions of the original array need not match so long as there is an
         appropriate conversion in the specified equivalency.
@@ -1016,6 +1030,8 @@ class unyt_array(np.ndarray):
         if self.has_equivalent(equivalence):
             this_equiv.convert(self, conv_unit.dimensions, **kwargs)
             self.convert_to_units(conv_unit)
+            # set name to None since the semantic meaning has changed
+            self.name = None
         else:
             raise InvalidUnitEquivalence(equivalence, self.units, conv_unit)
 
@@ -1584,7 +1600,9 @@ class unyt_array(np.ndarray):
     def __getitem__(self, item):
         ret = super(unyt_array, self).__getitem__(item)
         if ret.shape == ():
-            return unyt_quantity(ret, self.units, bypass_validation=True)
+            return unyt_quantity(
+                ret, self.units, bypass_validation=True, name=self.name
+            )
         else:
             if hasattr(self, "units"):
                 ret.units = self.units
@@ -1666,7 +1684,7 @@ class unyt_array(np.ndarray):
                     if u1.units.is_dimensionless:
                         pass
                     else:
-                        raise UnitOperationError(ufunc, u0, u1)
+                        raise UnitOperationError(ufunc, u0, u1.units)
                 if u1.shape == ():
                     u1 = float(u1)
                 else:
@@ -1845,10 +1863,16 @@ class unyt_array(np.ndarray):
          [4 5 6]] km
 
         """
-        return type(self)(np.copy(np.asarray(self)), self.units)
+        name = getattr(self, "name", None)
+        try:
+            return type(self)(np.copy(np.asarray(self)), self.units, name=name)
+        except TypeError:
+            # subclasses might not take name as a kwarg
+            return type(self)(np.copy(np.asarray(self)), self.units)
 
     def __array_finalize__(self, obj):
         self.units = getattr(obj, "units", NULL_UNIT)
+        self.name = getattr(obj, "name", None)
 
     def __pos__(self):
         """ Posify the data. """
@@ -1910,6 +1934,7 @@ class unyt_array(np.ndarray):
         """
         super(unyt_array, self).__setstate__(state[1:])
         unit, lut = state[0]
+        lut = _correct_old_unit_registry(lut)
         registry = UnitRegistry(lut=lut, add_default_symbols=False)
         self.units = Unit(unit, registry=registry)
 
@@ -1919,7 +1944,11 @@ class unyt_array(np.ndarray):
         This is necessary for stdlib deepcopy of arrays and quantities.
         """
         ret = super(unyt_array, self).__deepcopy__(memodict)
-        return type(self)(ret, copy.deepcopy(self.units))
+        try:
+            return type(self)(ret, copy.deepcopy(self.units), name=self.name)
+        except TypeError:
+            # subclasses might not take name as a kwarg
+            return type(self)(ret, copy.deepcopy(self.units))
 
 
 class unyt_quantity(unyt_array):
@@ -1941,6 +1970,10 @@ class unyt_quantity(unyt_array):
         of the registry associated with the unit object.
     dtype : data-type
         The dtype of the array data.
+    name : string
+        The name of the scalar. Defaults to None. This attribute does not propagate
+        through mathematical operations, but is preserved under indexing
+        and unit conversions.
 
     Examples
     --------
@@ -1975,6 +2008,7 @@ class unyt_quantity(unyt_array):
         dtype=None,
         bypass_validation=False,
         input_units=None,
+        name=None,
     ):
         if input_units is not None:
             warnings.warn(
@@ -2000,6 +2034,7 @@ class unyt_quantity(unyt_array):
             registry,
             dtype=dtype,
             bypass_validation=bypass_validation,
+            name=name,
         )
         if ret.size > 1:
             raise RuntimeError("unyt_quantity instances must be scalars")
