@@ -1,7 +1,11 @@
 """
-Register unyt_array with Matplotlib if it is available
-
+Matplotlib offers support for custom classes, such as unyt_array, allowing customization
+of axis information and unit conversion. In the case of unyt, the axis label is set
+based on the unyt_array.name and unyt_array.units attributes. It is also possible to
+convert the plotted units.
 
+This feature is optional and has to be enabled using the matplotlib_support context
+manager.
 """
 
 # -----------------------------------------------------------------------------
@@ -18,12 +22,28 @@ try:
 except ImportError:
     pass
 else:
+    from weakref import WeakKeyDictionary
     from unyt import unyt_array, unyt_quantity, Unit
 
+    __all__ = ["matplotlib_support"]
+
     class unyt_arrayConverter(ConversionInterface):
         """Matplotlib interface for unyt_array"""
 
+        _instance = None
         _labelstyle = "()"
+        _axisnames = WeakKeyDictionary()
+
+        # ensure that unyt_arrayConverter is a singleton
+        def __new__(cls):
+            if unyt_arrayConverter._instance is None:
+                unyt_arrayConverter._instance = super().__new__(cls)
+            return unyt_arrayConverter._instance
+
+        # When matplotlib first encounters a type in its units.registry, it will
+        # call default_units to obtain the units. Then it calls axisinfo to
+        # customize the axis - in our case, just set the label. Then matplotlib calls
+        # convert.
 
         @staticmethod
         def axisinfo(unit, axis):
@@ -47,24 +67,25 @@ else:
             """
             if isinstance(unit, tuple):
                 unit = unit[0]
-            unit_obj = Unit(unit)
+            unit_obj = unit if isinstance(unit, Unit) else Unit(unit)
+            name = unyt_arrayConverter._axisnames.get(axis, "")
             if unit_obj.is_dimensionless:
-                label = ""
+                label = name
             else:
+                name += " "
                 unit_str = unit_obj.latex_representation()
                 if unyt_arrayConverter._labelstyle == "[]":
-                    label = "$\\left[" + unit_str + "\\right]$"
+                    label = name + "$\\left[" + unit_str + "\\right]$"
                 elif unyt_arrayConverter._labelstyle == "/":
-                    axsym = axis.axis_name
+                    axsym = "$q_{\\rm" + axis.axis_name + "}$"
+                    name = axsym if name == " " else name
                     if "/" in unit_str:
-                        label = (
-                            "$q_{" + axsym + "}\\;/\\;\\left(" + unit_str + "\\right)$"
-                        )
+                        label = name + "$\\;/\\;\\left(" + unit_str + "\\right)$"
                     else:
-                        label = "$q_{" + axsym + "}\\;/\\;" + unit_str + "$"
+                        label = name + "$\\;/\\;" + unit_str + "$"
                 else:
-                    label = "$\\left(" + unit_str + "\\right)$"
-            return AxisInfo(label=label)
+                    label = name + "$\\left(" + unit_str + "\\right)$"
+            return AxisInfo(label=label.strip())
 
         @staticmethod
         def default_units(x, axis):
@@ -81,6 +102,11 @@ else:
 
             Unit object
             """
+            name = getattr(x, "name", "")
+            # maintain a mapping between Axis and name since Axis does not point to
+            # its underlying data and we want to propagate the name to the axis
+            # label in the subsequent call to axisinfo
+            unyt_arrayConverter._axisnames[axis] = name if name is not None else ""
             return x.units
 
         @staticmethod
@@ -124,7 +150,10 @@ else:
             return converted_value
 
     class matplotlib_support:
-        """Context manager for setting up integration with Unyt in Matplotlib
+        """Context manager for enabling the feature
+
+        When used in a with statement, the feature is enabled during the context and
+        then disabled after it exits.
 
         Parameters
         ----------
@@ -141,6 +170,7 @@ else:
         def __init__(self, label_style="()"):
             self._labelstyle = label_style
             unyt_arrayConverter._labelstyle = label_style
+            self._enabled = False
 
         def __call__(self):
             self.__enter__()
@@ -164,13 +194,16 @@ else:
         def __enter__(self):
             registry[unyt_array] = unyt_arrayConverter()
             registry[unyt_quantity] = unyt_arrayConverter()
+            self._enabled = True
 
         def __exit__(self, exc_type, exc_val, exc_tb):
             registry.pop(unyt_array)
             registry.pop(unyt_quantity)
+            self._enabled = False
 
         def enable(self):
             self.__enter__()
 
         def disable(self):
-            self.__exit__(None, None, None)
+            if self._enabled:
+                self.__exit__(None, None, None)
