@@ -446,6 +446,16 @@ def test_invalid_operations():
         u1 /= u2
     with pytest.raises(InvalidUnitOperation):
         u1 / "hello!"
+    with pytest.raises(InvalidUnitOperation):
+        Unit("B") * Unit("V")
+    with pytest.raises(InvalidUnitOperation):
+        Unit("V") * Unit("B")
+    with pytest.raises(InvalidUnitOperation):
+        Unit("V") / Unit("Np")
+    with pytest.raises(InvalidUnitOperation):
+        Unit("dB") / Unit("dB")
+    with pytest.raises(InvalidUnitOperation):
+        Unit("B") ** 2
 
 
 def test_base_equivalent():
@@ -748,6 +758,23 @@ def test_name_alternatives():
         assert hasattr(unyt.unit_symbols, name)
 
 
+def test_solar_unit_name_alternatives():
+    import unyt
+    from unyt import Unit
+
+    # check that m_sun, m_Sun, M_sun, M_Sun, msun, and Msun all work
+    for lower_name_prefix in "mrltz":
+        base_name = lower_name_prefix + "sun"
+        for name_prefix in [lower_name_prefix, lower_name_prefix.upper()]:
+            alternative_names = [name_prefix + suf for suf in ["sun", "_sun", "_Sun"]]
+            for name in alternative_names:
+                assert Unit(name) == Unit(base_name)
+                assert hasattr(unyt, name)
+                # only solar mass units are in physical constants
+                if lower_name_prefix == "m":
+                    assert hasattr(unyt.physical_constants, name)
+
+
 def test_attosecond():
     from unyt import Unit, attosecond, second
 
@@ -759,8 +786,8 @@ def test_attosecond():
 def test_micro():
     from unyt import Unit
 
-    assert str(Unit("um")) == "µm"
-    assert str(Unit("us")) == "µs"
+    assert str(Unit("um")) == "μm"
+    assert str(Unit("us")) == "μs"
 
 
 def test_show_all_units_doc_table_ops():
@@ -802,3 +829,38 @@ def test_equal_has_same_hash():
     assert b == c
     assert hash(a) == hash(b)
     assert hash(b) == hash(c)
+
+
+def test_bel_neper():
+    assert Unit("B").dimensions == Unit("Np").dimensions
+    a = 1 * Unit("B") / (np.log(10) / 2)
+    assert_allclose_units(a.to("Np"), 1 * Unit("Np"))
+    a = 2 * Unit("B")
+    b = 20 * Unit("decibel")
+    assert (a == b).all()
+    c = 2 * Unit("Np")
+    d = 20 * Unit("decineper")
+    assert (c == d).all()
+    assert Unit("dB") ** 1 == Unit("dB")
+
+
+def test_henry():
+    assert (Unit("H") / Unit("Ω")).dimensions == time
+
+
+def test_degC():
+    assert Unit("degree_celsius") == Unit("degC")
+    assert Unit("degree_Celsius") == Unit("degC")
+    assert Unit("Celsius") == Unit("degC")
+    assert Unit("°C") == Unit("degC")
+    a = 1 * Unit("degC")
+    assert str(a) == "1 °C"
+
+
+def test_degF():
+    assert Unit("degree_fahrenheit") == Unit("degF")
+    assert Unit("degree_Fahrenheit") == Unit("degF")
+    assert Unit("Fahrenheit") == Unit("degF")
+    assert Unit("°F") == Unit("degF")
+    a = 1 * Unit("degF")
+    assert str(a) == "1 °F"
