@@ -63,7 +63,7 @@ from unyt.unit_symbols import cm, m, g, degree
 from unyt.unit_registry import UnitRegistry
 from unyt._on_demand_imports import _astropy, _h5py, _pint, NotAModule
 from unyt._physical_ratios import metallicity_sun, speed_of_light_cm_per_s
-from unyt import dimensions
+from unyt import dimensions, Unit
 
 
 def operate_and_compare(a, b, op, answer):
@@ -498,6 +498,12 @@ def test_power():
     with pytest.raises(UnitOperationError):
         np.power(cm_arr, unyt_quantity(3, "g"))
 
+    try:
+        np.power(cm_arr, unyt_quantity(3, "g"))
+    except UnitOperationError as err:
+        assert isinstance(err.unit1, Unit)
+        assert isinstance(err.unit2, Unit)
+
 
 def test_comparisons():
     """
@@ -1389,7 +1395,16 @@ def test_pint():
 
 def test_subclass():
     class unyt_a_subclass(unyt_array):
-        pass
+        def __new__(
+            cls, input_array, units=None, registry=None, bypass_validation=None
+        ):
+            return super(unyt_a_subclass, cls).__new__(
+                cls,
+                input_array,
+                units,
+                registry=registry,
+                bypass_validation=bypass_validation,
+            )
 
     a = unyt_a_subclass([4, 5, 6], "g")
     b = unyt_a_subclass([7, 8, 9], "kg")
@@ -1422,6 +1437,9 @@ def test_subclass():
     assert_isinstance(a[:], unyt_a_subclass)
     assert_isinstance(a[:2], unyt_a_subclass)
     assert_isinstance(unyt_a_subclass(yta), unyt_a_subclass)
+    assert_isinstance(a.to("kg"), unyt_a_subclass)
+    assert_isinstance(a.copy(), unyt_a_subclass)
+    assert_isinstance(copy.deepcopy(a), unyt_a_subclass)
 
     with pytest.raises(RuntimeError):
         a + "hello"
@@ -2320,3 +2338,44 @@ def test_clip():
     assert positions.units == left_edge.units
     assert positions.max() == 1.0 * km
     assert positions.min() == 0.0 * km
+
+
+def test_name_attribute():
+    a = unyt_array([0, 1, 2], "s")
+    assert a.name is None
+    a.name = "time"
+    assert a.name == "time"
+    assert a[0].name == "time"
+    a.convert_to_units("ms")
+    assert a.name == "time"
+    b = unyt_quantity(1, "m", name="distance")
+    assert b.name == "distance"
+    c = b.copy()
+    assert c.name == "distance"
+    c_1 = copy.deepcopy(b)
+    assert c_1.name == "distance"
+    d = b.in_units("mm")
+    assert d.name == "distance"
+    e = b.to("mm")
+    assert e.name == "distance"
+    f = unyt_array([3, 4, 5], "K", name="temperature")
+    g = f.in_units("J", equivalence="thermal")
+    assert g.name is None
+    g_1 = f.to_equivalent("J", equivalence="thermal")
+    assert g_1.name is None
+    f.convert_to_equivalent("J", equivalence="thermal")
+    assert f.name is None
+    h = f.to("J", equivalence="thermal")
+    assert h.name is None
+
+
+def test_neper_bel():
+    assert 0 * Unit("dB") + 20 * Unit("dB") == unyt_quantity(20, "dB")
+    with pytest.raises(InvalidUnitOperation):
+        unyt_array([1, 10], "V") * Unit("dB")
+    with pytest.raises(InvalidUnitOperation):
+        Unit("Np") * unyt_array([1, 10], "s")
+    with pytest.raises(InvalidUnitOperation):
+        unyt_array([0, 20], "dB") ** 2
+    with pytest.raises(InvalidUnitOperation):
+        np.power(unyt_array([0, 20], "dB"), -2)
