@@ -42,6 +42,7 @@ from unyt.dimensions import (
     dimensionless,
     temperature,
     current_mks,
+    logarithmic,
 )
 import unyt.dimensions as dims
 from unyt.equivalencies import equivalence_registry
@@ -330,8 +331,13 @@ class Unit(object):
     def __str__(self):
         if self.expr == sympy_one:
             return "dimensionless"
+        unit_str = self.expr.__str__()
+        if unit_str == "degC":
+            return "°C"
+        if unit_str == "degF":
+            return "°F"
         # @todo: don't use dunder method?
-        return self.expr.__str__()
+        return unit_str
 
     #
     # Start unit operations
@@ -378,6 +384,10 @@ class Unit(object):
             data = np.array(u, subok=True)
             unit = getattr(u, "units", None)
             if unit is not None:
+                if self.dimensions is logarithmic:
+                    raise InvalidUnitOperation(
+                        "Tried to multiply '%s' and '%s'." % (self, unit)
+                    )
                 units = unit * self
             else:
                 units = self
@@ -389,6 +399,10 @@ class Unit(object):
             if data.shape == ():
                 return _import_cache_singleton.uq(data, units, bypass_validation=True)
             return _import_cache_singleton.ua(data, units, bypass_validation=True)
+        elif self.dimensions is logarithmic and not u.is_dimensionless:
+            raise InvalidUnitOperation("Tried to multiply '%s' and '%s'." % (self, u))
+        elif u.dimensions is logarithmic and not self.is_dimensionless:
+            raise InvalidUnitOperation("Tried to multiply '%s' and '%s'." % (self, u))
 
         base_offset = 0.0
         if self.base_offset or u.base_offset:
@@ -422,6 +436,10 @@ class Unit(object):
                     "Tried to divide a Unit object by '%s' (type %s). This "
                     "behavior is undefined." % (u, type(u))
                 )
+        elif self.dimensions is logarithmic and not u.is_dimensionless:
+            raise InvalidUnitOperation("Tried to divide '%s' and '%s'." % (self, u))
+        elif u.dimensions is logarithmic and not self.is_dimensionless:
+            raise InvalidUnitOperation("Tried to divide '%s' and '%s'." % (self, u))
 
         base_offset = 0.0
         if self.base_offset or u.base_offset:
@@ -455,6 +473,9 @@ class Unit(object):
                 "it to a float." % (p, type(p))
             )
 
+        if self.dimensions is logarithmic and p != 1.0:
+            raise InvalidUnitOperation("Tried to raise '%s' to power '%s'" % (self, p))
+
         return Unit(
             self.expr ** p,
             base_value=(self.base_value ** p),
