@@ -258,28 +258,7 @@ class UnitRegistry:
            A string containing a json represention of a UnitRegistry
         """
         data = json.loads(json_text)
-        lut = {}
-        for k, v in data.items():
-            unsan_v = list(v)
-            unsan_v[1] = cached_sympify(v[1])
-            if len(unsan_v) == 4:
-                # old unit registry so we need to add SI-prefixability to the registry
-                # entry and correct the base_value to be in MKS units
-                if k in default_unit_symbol_lut:
-                    unsan_v.append(default_unit_symbol_lut[k][4])
-                else:
-                    unsan_v.append(False)
-                dims = unsan_v[1]
-                for dim_factor in dims.as_ordered_factors():
-                    dim, power = dim_factor.as_base_exp()
-                    if dim == unyt_dims.mass:
-                        unsan_v[0] /= 1000 ** float(power)
-                    if dim == unyt_dims.length:
-                        unsan_v[0] /= 100 ** float(power)
-            lut[k] = tuple(unsan_v)
-        for k in default_unit_symbol_lut:
-            if k not in lut:
-                lut[k] = default_unit_symbol_lut[k]
+        lut = _correct_old_unit_registry(data, sympify=True)
         return cls(lut=lut, add_default_symbols=False)
 
     def list_same_dimensions(self, unit_object):
@@ -351,3 +330,30 @@ def _lookup_unit_symbol(symbol_str, unit_symbol_lut):
     raise UnitParseError(
         "Could not find unit symbol '%s' in the provided " "symbols." % symbol_str
     )
+
+
+def _correct_old_unit_registry(data, sympify=False):
+    lut = {}
+    for k, v in data.items():
+        unsan_v = list(v)
+        if sympify:
+            unsan_v[1] = cached_sympify(v[1])
+        if len(unsan_v) == 4:
+            # old unit registry so we need to add SI-prefixability to the registry
+            # entry and correct the base_value to be in MKS units
+            if k in default_unit_symbol_lut:
+                unsan_v.append(default_unit_symbol_lut[k][4])
+            else:
+                unsan_v.append(False)
+            dims = unsan_v[1]
+            for dim_factor in dims.as_ordered_factors():
+                dim, power = dim_factor.as_base_exp()
+                if dim == unyt_dims.mass:
+                    unsan_v[0] /= 1000 ** float(power)
+                if dim == unyt_dims.length:
+                    unsan_v[0] /= 100 ** float(power)
+        lut[k] = tuple(unsan_v)
+    for k in default_unit_symbol_lut:
+        if k not in lut:
+            lut[k] = default_unit_symbol_lut[k]
+    return lut
